==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/da.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU information er ikke tilgængeli",
    "Load average" : "Gennemsnitlig belastning",
    "Last minute" : "Senest minut",
    "Memory info not available" : "Hukommelsesinformation er ikke tilgængelig. ",
    "Total" : "Total",
    "Current usage" : "Nuværende forbrug",
    "Users" : "Brugere",
    "Groups" : "Grupper",
    "Links" : "Links",
    "Mails" : "Mails",
    "Federated sent" : "Fødereret sendt",
    "Federated received" : "Fødereret modtaget",
    "Talk conversations" : "Snak samtaler",
    "24 hours" : "24 timer",
    "1 hour" : "1 time",
    "Copy" : "Kopier",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "System" : "System",
    "Monitoring" : "Monitorering",
    "Monitoring app with useful server information" : "Monitoreringsapp med serverinformation",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Viser serverinformation som CPU belastning, RAM forbrug, lagerforbrug, antal brugere osv.",
    "Size" : "Størrelse",
    "Files:" : "Filer:",
    "Storages:" : "Lagre:",
    "Free Space:" : "Ledig plads:",
    "Hostname" : "Værtsnavn",
    "Status" : "Status",
    "Active users" : "Aktive brugere",
    "Shares" : "Delinger",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory Limit:" : "Hukommelses begrænsning:",
    "Max Execution Time:" : "Max Kørsels Tid:",
    "Upload max size:" : "Max upload størrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Størrelse:",
    "External monitoring tool" : "Eksternt monitoreringsværktøj",
    "You can connect an external monitoring tool by using this end point:" : "Du kan forbinde et eksternt monitoreringsprogram ved at bruge dette endepunkt:",
    "Did you know?" : "Vidste du?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Tilføj \"?format=json\" til slutningen af URLen for at hente resultatet i JSON format!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/da.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU information er ikke tilgængeli",
    "Load average" : "Gennemsnitlig belastning",
    "Last minute" : "Senest minut",
    "Memory info not available" : "Hukommelsesinformation er ikke tilgængelig. ",
    "Total" : "Total",
    "Current usage" : "Nuværende forbrug",
    "Users" : "Brugere",
    "Groups" : "Grupper",
    "Links" : "Links",
    "Mails" : "Mails",
    "Federated sent" : "Fødereret sendt",
    "Federated received" : "Fødereret modtaget",
    "Talk conversations" : "Snak samtaler",
    "24 hours" : "24 timer",
    "1 hour" : "1 time",
    "5 mins" : "5 mins",
    "Copy" : "Kopier",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "System" : "System",
    "Monitoring" : "Monitorering",
    "Monitoring app with useful server information" : "Monitoreringsapp med serverinformation",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Viser serverinformation som CPU belastning, RAM forbrug, lagerforbrug, antal brugere osv.",
    "Operating System" : "Operativ system",
    "CPU" : "CPU",
    "Memory" : "Hukommelse",
    "Server time" : "Server tid",
    "Uptime" : "Oppetid",
    "Load" : "Belastning",
    "Disk" : "Disk",
    "Mount" : "Mount",
    "Filesystem" : "Filsystem",
    "Size" : "Størrelse",
    "Available" : "Tilgængelig",
    "Used" : "Forbrugt",
    "You will get a notification once one of your disks is nearly full." : "Du får en meddelelse, når en af dine diske er næsten fuld.",
    "Files:" : "Filer:",
    "Storages:" : "Lagre:",
    "Free Space:" : "Ledig plads:",
    "Network" : "Netværk",
    "Hostname" : "Værtsnavn",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Hastighed",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktive brugere",
    "Total users:" : "Antal brugere:",
    "Shares" : "Delinger",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory Limit:" : "Hukommelses begrænsning:",
    "Max Execution Time:" : "Max Kørsels Tid:",
    "Upload max size:" : "Max upload størrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Størrelse:",
    "External monitoring tool" : "Eksternt monitoreringsværktøj",
    "You can connect an external monitoring tool by using this end point:" : "Du kan forbinde et eksternt monitoreringsprogram ved at bruge dette endepunkt:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ved at tilføje \"?format=json\" i slutningen af URL'en får du resultatet i JSON.",
    "To use an access token please generate one then set it using the following command:" : "For at bruge et adgangstoken skal du generere et og derefter indstille det ved hjælp af følgende kommando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Send derefter tokenet med \"NC-Token\"-headeren, når du forespørger på ovenstående URL.",
    "Time Servers" : "Time Servers"
},
"nplurals=2; plural=(n != 1);");
